.. _client-library:

*********************
Python Client Library
*********************

This is the GA4GH client API library. This is a convenient wrapper for
the low-level HTTP GA4GH API, and abstracts away network centric
details such as paging.  The methods and types used by the client
library are defined by the
`GA4GH schema <https://ga4gh-schemas.readthedocs.org/en/latest/>`_.


.. warning:: This client API should be considered early alpha quality,
          and may change in arbitrary ways.

.. todo:: A full description of this API and links to a tutorial on how
       to use it, as well as a quickstart showing the basic usage.

-----
Types
-----

.. todo:: Add links to the upstream documentation for the GA4GH types.

----------
Client API
----------

.. todo:: Add overview documentation for the client API.

.. automodule:: ga4gh.client.client
    :members:

